@@ -6,6 +6,8 @@ https://github.com/eic/ip6
 """
 
 import os
+import sys
+import platform
 
 from edpm.engine.commands import run, workdir
 from edpm.engine.env_gen import Set, Prepend
@@ -54,6 +56,13 @@ class EcceDetectorRecipe(Recipe):
         self.config['clone_command_ip6'] = "git clone -b {branch_ip6} {repo_address_ip6} {source_path_ip6}" \
             .format(**self.config)
 
+        # Because in general we await install_path to be set to something
+        self.config['install_path'] = self.config['install_path_ecce']
+
+        # Link ip6 repo to ecce, as IP6 should be linked to installed ECCE
+        self.config['ip6_link_source'] = "{install_path_ip6}/share/ip6".format(**self.config)
+        self.config['ip6_link_target'] = "{install_path_ecce}/share/ecce/ip6".format(**self.config)
+
         # cmake command:
         # the  -Wno-dev  flag is to ignore the project developers cmake warnings for policy CMP0075
         self.config['build_cmd_ecce'] = "cmake -w -DCMAKE_INSTALL_PREFIX={install_path_ecce} -DCMAKE_CXX_STANDARD={cxx_standard} {source_path_ecce}" \
@@ -106,7 +115,12 @@ class EcceDetectorRecipe(Recipe):
         # Create build directory
         self.build(self.config['build_path_ip6'], self.config['build_cmd_ip6'])
         self.build(self.config['build_path_ecce'], self.config['build_cmd_ecce'])
-        run("ln -s {install_path_ip6}/share/ip6 {install_path_ecce}/share/ecce/ip6")
+
+        # Link ip6 repo to ecce
+        if os.path.islink(self.config['ip6_link_target']):
+            run("unlink {ip6_link_target}".format(**self.config))
+        run("ln -s {ip6_link_source} {ip6_link_target}".format(**self.config))
+
 
     def step_reinstall(self):
         """Delete everything and start over"""
@@ -121,15 +135,23 @@ class EcceDetectorRecipe(Recipe):
     def gen_env(data):
         """Generates environments to be set"""
 
-        if 'source_path' in data.keys():
-            source_path = data['source_path']
-        else:
-            source_path = data['install_path']
+        install_path = data['built_with_config']['install_path_ecce']
+        # print(data)
+        # exit(1)
+        ecce_lib_path = os.path.join(data['built_with_config']['install_path_ecce'], 'lib')
+        ip6_lib_path = os.path.join(data['built_with_config']['install_path_ip6'], 'lib')
 
-        yield Prepend('PATH', os.path.join(data['install_path'], 'bin'))  # to make available clhep-config and others
-        yield Prepend('PYTHONPATH', os.path.join(data['install_path'], 'python'))  # to make g4epy available
-        yield Set('G4E_HOME', source_path)                         # where 'resources' are
-        yield Set('G4E_MACRO_PATH', source_path)
+        yield Set('DETECTOR_PATH', os.path.join(install_path, 'share', 'ecce'))
+
+        if platform.system() == 'Darwin':
+            yield Prepend('DYLD_LIBRARY_PATH', ecce_lib_path)
+            yield Prepend('DYLD_LIBRARY_PATH', ip6_lib_path)
+
+        yield Prepend('LD_LIBRARY_PATH', ecce_lib_path)
+        yield Prepend('LD_LIBRARY_PATH', ip6_lib_path)
+
+        yield Set('EIC_DD4HEP_HOME', data['built_with_config']['install_path_ecce'])
+        yield Set('IP6_DD4HEP_HOME', data['built_with_config']['install_path_ip6'])
 
 
     #
